@@ -27,6 +27,8 @@ dependences="python3-dbus python3-dbus.mainloop.qt"
 
 import dbus, subprocess, os, os.path, re, time, threading, logging, inspect
 from dbus.mainloop.glib import DBusGMainLoop, threads_init
+import gi
+gi.require_version('UDisks', '2.0')
 from gi.repository import Gio, GLib, UDisks
 from PyQt5.QtWidgets import *
 
@@ -126,17 +128,21 @@ class UDisksBackend:
     et pas des disques branchés sur d'autres bus.
     """
     
-    def __init__(self, logger=logging, diskClass=object):
+    def __init__(self, logger=logging, diskClass=object, onlyUsb=True):
         """
         Le constructeur.
         :param logger: un objet permettant de journaliser les messages ; 
-        par défaut il se confond avec le module logging
+          par défaut il se confond avec le module logging
         :type logger: un module tel que logging
-        :param diskClass: la classe à utiliser pour créer des instances de disques
+        :param diskClass: la classe à utiliser pour créer des
+          instances de disques
         :type diskClass: class
+        :param onlyUsb: si vrai (par défaut), on ne considère que les
+          disque usb.
         """
         self.install_thread = None
         self.logger=logger
+        self.onlyUsb = onlyUsb
         ## self.targets est un dictionnaire des disques détectés
         ## les clés sont les paths et les contenus des instances de diskClass
         self.diskClass=diskClass
@@ -194,7 +200,7 @@ class UDisksBackend:
         :type  func: fonction sans paramètres
         :return: le résultat de l'appel à self.manager.connect(signal,func)
         """
-        if inspect.getargspec(func).args == self.cbHooks[signal]['profile']:
+        if inspect.getfullargspec(func).args == self.cbHooks[signal]['profile']:
             cb=self.manager.connect(signal,func)
             self.cbHooks[signal]['hooks'].append(cb)
             return cb
@@ -331,14 +337,13 @@ class UDisksBackend:
                     logging.exception(QApplication.translate("uDisk","Failed to mount the disk: %s",None) % path)
         if mount:
             total, free = fs_size(mount)
-        isUsb=self.objIsUsb(obj)
-        if not isUsb:
+        if self.onlyUsb and not self.objIsUsb(obj):
             self.logger.debug(QApplication.translate("uDisk","Disk not added: not a USB partition",None)+inspectData())
         elif total < 1:
             self.logger.debug(QApplication.translate("uDisk","Disk not added: empty partition",None)+inspectData())
         else:
             udisk=self.diskClass(
-                path=path, mp=mount, isUsb=isUsb,
+                path=path, mp=mount, isUsb=self.objIsUsb(obj),
                 vendor=drive.get_cached_property('Vendor').get_string(),
                 model=drive.get_cached_property('Model').get_string(),
                 parent=safePath(parent),
@@ -377,7 +382,7 @@ class UDisksBackend:
             return
         """
         isUsb = self.objIsUsb(obj)
-        if not isUsb:
+        if self.onlyUsb and not isUsb:
             self.logger.debug(QApplication.translate("uDisk","Disk not added: not a USB partition",None)+inspectData())
         else:
             udisk=self.diskClass(
@@ -650,15 +655,24 @@ class Available (UDisksBackend):
 
     """
 
-    def __init__(self, access="disk", diskClass=uDisk2):
+    def __init__(self, access="disk", diskClass=uDisk2, logger=logging):
         """
         Le constructeur
-        :param access: définit le type d'accès souhaité. Par défaut, c'est "disk"
-          c'est à dire qu'on veut la liste des disques USB. Autres valeurs
-          possibles : "firstFat" pour les premières partitions vfat.
+        :param access: définit le type d'accès souhaité. Par défaut,
+          c'est "disk" c'est à dire qu'on veut la liste des disques USB.
+          Autres valeurs possibles : "firstFat" pour les premières 
+          partitions vfat, "all" pour tout type de disques.
         :param diskClass: la classe de disques à créer
+        :param logger: le système de journalisation
+        :param onlyUsb: si vrai (par défaut), on ne considère que les
+          disques USB
         """
-        UDisksBackend.__init__(self, diskClass=diskClass)
+        UDisksBackend.__init__(
+            self,
+            diskClass=diskClass,
+            logger=logger,
+            onlyUsb = access!="all"
+        )
         self.access=access
         self.detect_devices()
         self.finishInit()
@@ -774,6 +788,8 @@ class Available (UDisksBackend):
         :rtype: str
         """
         r=  "Available USB disks\n"
+        if not self.onlyUsb:
+            r = "Available disks\n"
         r+= "===================\n"
         for d in sorted(self.disks()):
             r+="%s\n" %(self.targets[d].devStuff)
@@ -820,7 +836,7 @@ class Available (UDisksBackend):
         :return: le nième disque USB connecté
         :rtype: uDisk2
         """
-        if self.access=="disk":
+        if self.access=="disk" or self.access=="all":
             path=self.targets.keys()[n]
         elif self.access=="firstFat":
             path=self.firstFats[n]
@@ -833,7 +849,7 @@ class Available (UDisksBackend):
         :return: la longueur de la collection de disques renvoyée
         :rtype: int
         """
-        if self.access=="disk":
+        if self.access=="disk" or self.access=="all":
             return len(self.targets)
         elif self.access=="firstFat":
             return len(self.firstFats)
@@ -871,4 +887,9 @@ class Available (UDisksBackend):
                 return True
         return False
     
-##################### fin de la définition de la calsse uDisk2 ################
+if __name__ == "__main__":
+    logging.basicConfig(level=logging.DEBUG)
+    a = Available(access="all")
+    print(a)
+    
+
